@@ -8,6 +8,7 @@ use crate::{
 use std::env::current_dir;
 use std::error::Error;
 use std::fs::OpenOptions;
+use std::fs::{read_to_string, File};
 use std::io::prelude::*;
 use std::io::BufReader;
 use std::path::Path;
@@ -269,27 +270,39 @@ pub fn delete_tririga_object_from_config() -> Result<(), Box<dyn Error>> {
 /// Exit if line already exist.
 fn add_config_to_git_ignore() -> Result<(), Box<dyn Error>> {
 	let file_path = ".gitignore";
+	let tririga_yaml_file_name = "tririga.yaml";
 	if Path::new(file_path).exists() {
 		let file = std::fs::File::open(file_path)?;
-		let reader = BufReader::new(file);
+		let reader = BufReader::new(&file);
 		for line in reader.lines() {
 			match line {
 				Ok(line) => {
-					if line.contains(TRIRIGA_CONFIG_PATH) {
+					if line.contains(tririga_yaml_file_name) {
 						return Ok(());
 					}
 				}
 				Err(e) => println!("ERROR: {}", e),
 			}
 		}
+		// If there is already a line in .gitignore file, write a line skip then append 'tririga.yaml'
+		let mut file = OpenOptions::new()
+			.write(true)
+			.append(true)
+			.open(&file_path)
+			.unwrap();
+		if read_to_string(tririga_yaml_file_name)?.len() > 0 {
+			println!("There is something in the .gitignore file. Skipping a line to write");
+			if let Err(e) = writeln!(file) {
+				eprintln!("Couldn't write to file: {}", e);
+			}
+		}
+		if let Err(e) = write!(file, "{}", tririga_yaml_file_name) {
+			eprintln!("Couldn't write to file: {}", e);
+		}
+		return Ok(());
 	}
-	let mut git_ignore = OpenOptions::new()
-		.create(true)
-		.write(true)
-		.append(true)
-		.open(".gitignore")
-		.unwrap();
-	if let Err(e) = writeln!(git_ignore, "\n{}", TRIRIGA_CONFIG_PATH) {
+	let mut git_ignore = File::create(Path::new(file_path))?;
+	if let Err(e) = write!(git_ignore, "{}", tririga_yaml_file_name) {
 		eprintln!("Couldn't write to file: {}", e);
 	}
 	Ok(())
